Introduction
============

.. toctree::
  :maxdepth: 2
  :hidden:

  tomarchitecture
  getting_started
  workflow
  resources
  faqs
  troubleshooting

:doc:`Architecture <tomarchitecture>` - This document describes the architecture of the TOM Toolkit at a
high level. Read this first if you're interested in how the TOM Toolkit works.

:doc:`Getting Started <getting_started>` - First steps for getting a TOM up and running.

:doc:`Workflow <workflow>` - The general workflow used with TOMs.

:doc:`Programming Resources <resources>` - Resources for learning the elements of programming used in the TOM Toolkit:
HTML, CSS, Python, and Django

:doc:`Frequently Asked Questions <faqs>` - Look here for a potential quick answer to a common question.

:doc:`Troubleshooting <troubleshooting>` - Find solutions to common problems or information on how to debug an issue.